@@ -6,13 +6,14 @@ use Carp;
 
 #use Data::Dump qw( dump );
 
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 
 __PACKAGE__->mk_ro_accessors(
     qw(
         plain
         html
         term
+        term_re
         is_phrase
         )
 );
@@ -40,6 +41,8 @@ Search::Tools::RegEx - regular expressions for terms
 
 =head2 term
 
+=head2 term_re
+
 =head2 is_phrase
 
 =cut
